==> react-molecule-phone-input-1.7.0.tgz: package/lib/index.js <==
import { useEffect, useRef, useState } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import flagIcons from 'rendered-country-flags';
import AtomIcon, { ATOM_ICON_COLORS, ATOM_ICON_SIZES } from '@s-ui/react-atom-icon';
import AtomInput from '@s-ui/react-atom-input';
import { TYPES } from '@s-ui/react-atom-input/lib/config.js';
import MoleculeDropdownList, { moleculeDropdownListDesigns } from '@s-ui/react-molecule-dropdown-list';
import MoleculeDropdownOption from '@s-ui/react-molecule-dropdown-option';
import { phoneValidationType } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var BASE_CLASS = 'sui-MoleculePhoneInput';
export default function MoleculePhoneInput(_ref) {
  var _cx;
  var dropdownCloseIcon = _ref.dropdownCloseIcon,
    dropdownIcon = _ref.dropdownIcon,
    _ref$value = _ref.value,
    value = _ref$value === void 0 ? '' : _ref$value,
    setFormattedValue = _ref.setFormattedValue,
    _ref$prefixes = _ref.prefixes,
    prefixes = _ref$prefixes === void 0 ? [] : _ref$prefixes,
    onChange = _ref.onChange,
    placeholder = _ref.placeholder,
    hasError = _ref.hasError,
    _ref$initialSelectedP = _ref.initialSelectedPrefix,
    initialSelectedPrefix = _ref$initialSelectedP === void 0 ? prefixes[0] : _ref$initialSelectedP,
    _ref$type = _ref.type,
    type = _ref$type === void 0 ? phoneValidationType.DEFAULT : _ref$type,
    _ref$visiblePrefixes = _ref.visiblePrefixes,
    visiblePrefixes = _ref$visiblePrefixes === void 0 ? true : _ref$visiblePrefixes;
  var _useState = useState(false),
    showDropdown = _useState[0],
    setShowDropdown = _useState[1];
  var _useState2 = useState(initialSelectedPrefix),
    selectedPrefix = _useState2[0],
    setSelectedPrefix = _useState2[1];
  var _useState3 = useState(false),
    isLandLine = _useState3[0],
    setIsLandLine = _useState3[1];
  var modalRef = useRef(null);
  var inputPrefixRef = useRef(null);
  var inputMask = selectedPrefix && {
    mask: isLandLine ? selectedPrefix.mask.landlineMask : selectedPrefix.mask.mobileMask
  };
  var baseClass = cx((_cx = {}, _cx["splitted"] = type === phoneValidationType.SPLITTED, _cx[BASE_CLASS + "--error"] = hasError, _cx), BASE_CLASS);

  // Close dropdown when click outside
  useEffect(function () {
    var handleClickOutside = function handleClickOutside(event) {
      if (modalRef.current && !modalRef.current.contains(event.target) && !inputPrefixRef.current.contains(event.target)) {
        setShowDropdown(false);
      }
    };
    document.addEventListener('mousedown', handleClickOutside);
    return function () {
      document.removeEventListener('mousedown', handleClickOutside);
    };
  }, []);
  var handlePhoneChange = function handlePhoneChange(e, _ref2) {
    var value = _ref2.value;
    if (selectedPrefix.landlinePrefixs.includes(value[0])) {
      setIsLandLine(true);
    } else {
      setIsLandLine(false);
    }
    typeof setFormattedValue === 'function' && setFormattedValue(value);
    typeof onChange === 'function' && onChange(e, {
      prefix: selectedPrefix.countryCode,
      // remove spaces from value
      value: value.toString().replace(/\s/g, ''),
      isLandLine: isLandLine
    });
  };
  return /*#__PURE__*/_jsxs("div", {
    className: baseClass,
    children: [/*#__PURE__*/_jsxs("div", {
      className: baseClass + "-input",
      children: [/*#__PURE__*/_jsxs("div", {
        ref: inputPrefixRef,
        className: baseClass + "-input-prefix",
        onClick: function onClick() {
          return setShowDropdown(!showDropdown);
        },
        children: [selectedPrefix && /*#__PURE__*/_jsx("img", {
          height: 24,
          width: 24,
          className: baseClass + "-input-prefix-flag",
          src: flagIcons[selectedPrefix == null ? void 0 : selectedPrefix.value]
        }), visiblePrefixes && /*#__PURE__*/_jsx(AtomIcon, {
          size: ATOM_ICON_SIZES.medium,
          color: ATOM_ICON_COLORS.currentColor,
          children: showDropdown ? dropdownCloseIcon : dropdownIcon
        })]
      }), /*#__PURE__*/_jsxs("div", {
        className: baseClass + "-input-phoneContainer",
        children: [selectedPrefix && /*#__PURE__*/_jsx("p", {
          className: baseClass + "-input-prefix-code",
          children: selectedPrefix.countryCode
        }), /*#__PURE__*/_jsx(AtomInput, {
          value: value.toString(),
          mask: inputMask,
          placeholder: placeholder,
          type: TYPES.MASK,
          onChange: handlePhoneChange,
          noBorder: true
        })]
      })]
    }), showDropdown && visiblePrefixes && /*#__PURE__*/_jsx("div", {
      className: baseClass + "-dropdown",
      children: /*#__PURE__*/_jsx(MoleculeDropdownList, {
        design: moleculeDropdownListDesigns.FLAT,
        ref: modalRef,
        visible: visiblePrefixes,
        children: prefixes.map(function (prefix) {
          return /*#__PURE__*/_jsx(MoleculeDropdownOption, {
            value: prefix.value,
            selected: selectedPrefix.value === prefix.value,
            onClick: function onClick() {
              setSelectedPrefix(prefix);
              setShowDropdown(false);
            },
            children: /*#__PURE__*/_jsxs("div", {
              className: baseClass + "-dropdown-option",
              children: [/*#__PURE__*/_jsx("img", {
                height: 24,
                width: 24,
                className: baseClass + "-dropdown-option-label",
                src: flagIcons[prefix.value]
              }), /*#__PURE__*/_jsx("span", {
                className: baseClass + "-dropdown-option-label",
                children: prefix.label
              }), /*#__PURE__*/_jsxs("span", {
                className: baseClass + "-dropdown-option-code",
                children: ["(", prefix.countryCode, ")"]
              })]
            })
          }, prefix.countryCode);
        })
      })
    })]
  });
}
MoleculePhoneInput.displayName = 'MoleculePhoneInput';

==> react-molecule-phone-input-1.8.0.tgz: package/lib/index.js <==
import { useEffect, useRef, useState } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import flagIcons from 'rendered-country-flags';
import { TYPES } from '@s-ui/react-atom-input/lib/config.js';
import MoleculeDropdownList, { moleculeDropdownListDesigns } from '@s-ui/react-molecule-dropdown-list';
import MoleculeDropdownOption from '@s-ui/react-molecule-dropdown-option';
import MoleculeInputField from '@s-ui/react-molecule-input-field';
import { phoneValidationType } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var BASE_CLASS = 'sui-MoleculePhoneInput';
export { PREFIXES } from './settings.js';
export default function MoleculePhoneInput(_ref) {
  var _cx;
  var alertText = _ref.alertText,
    _ref$autoHideHelpText = _ref.autoHideHelpText,
    autoHideHelpText = _ref$autoHideHelpText === void 0 ? false : _ref$autoHideHelpText,
    dropdownCloseIcon = _ref.dropdownCloseIcon,
    dropdownIcon = _ref.dropdownIcon,
    errorText = _ref.errorText,
    hasError = _ref.hasError,
    helpText = _ref.helpText,
    onChange = _ref.onChange,
    placeholder = _ref.placeholder,
    _ref$prefixes = _ref.prefixes,
    prefixes = _ref$prefixes === void 0 ? [] : _ref$prefixes,
    _ref$initialSelectedP = _ref.initialSelectedPrefix,
    initialSelectedPrefix = _ref$initialSelectedP === void 0 ? prefixes[0] : _ref$initialSelectedP,
    setFormattedValue = _ref.setFormattedValue,
    successText = _ref.successText,
    _ref$type = _ref.type,
    type = _ref$type === void 0 ? phoneValidationType.DEFAULT : _ref$type,
    _ref$value = _ref.value,
    value = _ref$value === void 0 ? '' : _ref$value,
    _ref$visiblePrefixes = _ref.visiblePrefixes,
    visiblePrefixes = _ref$visiblePrefixes === void 0 ? true : _ref$visiblePrefixes;
  var _useState = useState(false),
    showDropdown = _useState[0],
    setShowDropdown = _useState[1];
  var _useState2 = useState(initialSelectedPrefix),
    selectedPrefix = _useState2[0],
    setSelectedPrefix = _useState2[1];
  var _useState3 = useState(false),
    isLandLine = _useState3[0],
    setIsLandLine = _useState3[1];
  var modalRef = useRef(null);
  var inputPrefixRef = useRef(null);
  var inputMask = selectedPrefix && {
    mask: isLandLine ? selectedPrefix.mask.landlineMask : selectedPrefix.mask.mobileMask
  };
  var baseClass = cx((_cx = {}, _cx["splitted"] = type === phoneValidationType.SPLITTED, _cx[BASE_CLASS + "--error"] = hasError, _cx), BASE_CLASS);

  // Close dropdown when click outside
  useEffect(function () {
    var handleClickOutside = function handleClickOutside(event) {
      if (modalRef.current && !modalRef.current.contains(event.target) && !inputPrefixRef.current.contains(event.target)) {
        setShowDropdown(false);
      }
    };
    document.addEventListener('mousedown', handleClickOutside);
    return function () {
      document.removeEventListener('mousedown', handleClickOutside);
    };
  }, []);
  var handlePhoneChange = function handlePhoneChange(e, _ref2) {
    var value = _ref2.value;
    if (selectedPrefix.landlinePrefixs.includes(value[0])) {
      setIsLandLine(true);
    } else {
      setIsLandLine(false);
    }
    typeof setFormattedValue === 'function' && setFormattedValue(value);
    typeof onChange === 'function' && onChange(e, {
      prefix: selectedPrefix.countryCode,
      // remove spaces from value
      value: value.toString().replace(/\s/g, ''),
      isLandLine: isLandLine
    });
  };
  return /*#__PURE__*/_jsxs("div", {
    className: baseClass,
    children: [/*#__PURE__*/_jsxs("div", {
      className: baseClass + "-input",
      children: [/*#__PURE__*/_jsxs("div", {
        ref: inputPrefixRef,
        className: baseClass + "-input-prefix",
        onClick: function onClick() {
          return setShowDropdown(!showDropdown);
        },
        children: [selectedPrefix && /*#__PURE__*/_jsx("img", {
          height: 24,
          width: 24,
          className: baseClass + "-input-prefix-flag",
          src: flagIcons[selectedPrefix == null ? void 0 : selectedPrefix.value]
        }), visiblePrefixes && (showDropdown ? dropdownCloseIcon : dropdownIcon)]
      }), /*#__PURE__*/_jsxs("div", {
        className: baseClass + "-input-phoneContainer",
        children: [selectedPrefix && /*#__PURE__*/_jsx("p", {
          className: baseClass + "-input-prefix-code",
          children: selectedPrefix.countryCode
        }), /*#__PURE__*/_jsx(MoleculeInputField, {
          alertText: alertText,
          autoHideHelpText: autoHideHelpText,
          errorText: errorText,
          helpText: helpText,
          placeholder: placeholder,
          successText: successText,
          mask: inputMask,
          noBorder: true,
          onChange: handlePhoneChange,
          type: TYPES.MASK,
          value: value.toString()
        })]
      })]
    }), showDropdown && visiblePrefixes && /*#__PURE__*/_jsx("div", {
      className: baseClass + "-dropdown",
      children: /*#__PURE__*/_jsx(MoleculeDropdownList, {
        design: moleculeDropdownListDesigns.FLAT,
        ref: modalRef,
        visible: visiblePrefixes,
        children: prefixes.map(function (prefix) {
          return /*#__PURE__*/_jsx(MoleculeDropdownOption, {
            value: prefix.value,
            selected: selectedPrefix.value === prefix.value,
            onClick: function onClick() {
              setSelectedPrefix(prefix);
              setShowDropdown(false);
            },
            children: /*#__PURE__*/_jsxs("div", {
              className: baseClass + "-dropdown-option",
              children: [/*#__PURE__*/_jsx("img", {
                height: 24,
                width: 24,
                className: baseClass + "-dropdown-option-label",
                src: flagIcons[prefix.value]
              }), /*#__PURE__*/_jsx("span", {
                className: baseClass + "-dropdown-option-label",
                children: prefix.label
              }), /*#__PURE__*/_jsxs("span", {
                className: baseClass + "-dropdown-option-code",
                children: ["(", prefix.countryCode, ")"]
              })]
            })
          }, prefix.countryCode);
        })
      })
    })]
  });
}
MoleculePhoneInput.displayName = 'MoleculePhoneInput';
